#!/bin/bash


set -o nounset
set -o errexit

# set -x

function HMS()
{
    S=$1
    H=$((S/3600))
    S=$((S-$H*3600))
    M=$((S/60))
    S=$((S-$M*60))
    printf "%d:%02d:%02d" $H $M $S
}

# low level functions used to manipulate linux kernel-style .config
# files.

function SyncConfig()
{
    yes '' | $Make oldconfig >/dev/null
}

function UnsetValue()
{
    dosync=y
    test "$1" = '-n' && { dosync=n; shift; }
    Variable="$1"
    echo "UnsetValue $Variable"
    sed -i "s/^${Variable}=.*/# ${Variable} is not set/g" .config
    test $dosync = y && SyncConfig
    return 0
}

function SetValue()
{
    dosync=y
    test "$1" = '-n' && { dosync=n; shift; }
    Variable="$1"
    # default value is 'y'
    Value="${2-y}"
    echo "SetValue $Variable $Value"
    # if value isn't 'y', then put it in double quotes
    test "$Value" != y && Value="\"$Value\""
    # escape any slashes
    Value=${Value//\//\\\/}
    sed -i "s/^${Variable}=.*/${Variable}=${Value}/g" .config
    sed -i "s/^# ${Variable} is not set.*/${Variable}=${Value}/g" .config
    test $dosync = y && SyncConfig
    return 0
}

function UseExternalToolchain()
{
    TPath=""
    test -x $1/usr/bin/arm-linux-gcc && TPath="$1/usr"
    test -x $1/bin/arm-linux-gcc && TPath="$1"
    test -n "$TPath" || { echo "Could not find compiler under $1"; return 1; }
    SetValue      BR2_TOOLCHAIN_EXTERNAL_PATH "$TPath"
}

export BUILDROOT_DL_DIR="$(cd downloads;pwd)"
export ToolchainPath="$(cd ../toolchain;pwd)"

BuildrootVersion=2012.02

BRPath="$(cd buildroot-$BuildrootVersion;pwd)"

echo "***** started build at $(date) *****"

echo "***** Cleaning *****"
rm -f $(find custom-files -name '*~')
rm -rf output
mkdir output
pushd output >/dev/null

Make="make O=$PWD -C$BRPath"

echo "***** Setting up default config *****"
$Make comtrol-nextgen_defconfig
cp .config .config-orig
UseExternalToolchain "$ToolchainPath"

echo "***** starting make at $(date) *****"
MakeStatus=SUCCESS
$Make || MakeStatus=FAIL

echo "***** finished build $MakeStatus at $(date) *****"
echo "***** elapsed time $(HMS $SECONDS) *****"
